==> igniteui-react-charts-16.6.4.tgz: package/ES5/ItemwiseStrategyBasedIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { ItemwiseStrategyCalculationStrategy } from "./ItemwiseStrategyCalculationStrategy";
import { markType } from "igniteui-react-core/ES5/type";
var ItemwiseStrategyBasedIndicator = /** @class */ (function (_super) {
    tslib_1.__extends(ItemwiseStrategyBasedIndicator, _super);
    function ItemwiseStrategyBasedIndicator() {
        return _super.call(this) || this;
    }
    ItemwiseStrategyBasedIndicator.prototype.get_p3 = function () {
        return new ItemwiseStrategyCalculationStrategy();
    };
    Object.defineProperty(ItemwiseStrategyBasedIndicator.prototype, "p3", {
        get: function () {
            return this.get_p3();
        },
        enumerable: true,
        configurable: true
    });
    ItemwiseStrategyBasedIndicator.prototype.qh = function () {
        _super.prototype.qh.call(this);
        this.qo = this.qp;
        this.p2.c = this.qo;
    };
    ItemwiseStrategyBasedIndicator.$t = markType(ItemwiseStrategyBasedIndicator, 'ItemwiseStrategyBasedIndicator', StrategyBasedIndicator.$);
    return ItemwiseStrategyBasedIndicator;
}(StrategyBasedIndicator));
export { ItemwiseStrategyBasedIndicator };

==> igniteui-react-charts-16.6.8.tgz: package/ES5/ItemwiseStrategyBasedIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { ItemwiseStrategyCalculationStrategy } from "./ItemwiseStrategyCalculationStrategy";
import { markType } from "igniteui-react-core/ES5/type";
/**
 * @hidden
 */
var ItemwiseStrategyBasedIndicator = /** @class */ (function (_super) {
    tslib_1.__extends(ItemwiseStrategyBasedIndicator, _super);
    function ItemwiseStrategyBasedIndicator() {
        return _super.call(this) || this;
    }
    ItemwiseStrategyBasedIndicator.prototype.get_p5 = function () {
        return new ItemwiseStrategyCalculationStrategy();
    };
    Object.defineProperty(ItemwiseStrategyBasedIndicator.prototype, "p5", {
        get: function () {
            return this.get_p5();
        },
        enumerable: true,
        configurable: true
    });
    ItemwiseStrategyBasedIndicator.prototype.qj = function () {
        _super.prototype.qj.call(this);
        this.qq = this.qr;
        this.p4.c = this.qq;
    };
    ItemwiseStrategyBasedIndicator.$t = markType(ItemwiseStrategyBasedIndicator, 'ItemwiseStrategyBasedIndicator', StrategyBasedIndicator.$);
    return ItemwiseStrategyBasedIndicator;
}(StrategyBasedIndicator));
export { ItemwiseStrategyBasedIndicator };
